package de.ozgcloud.apilib.file.dummy;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import org.apache.commons.io.IOUtils;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.stereotype.Service;

import de.ozgcloud.apilib.file.OzgCloudFile;
import de.ozgcloud.apilib.file.OzgCloudFileId;
import de.ozgcloud.apilib.file.OzgCloudFileService;
import de.ozgcloud.apilib.file.OzgCloudUploadFile;
import de.ozgcloud.common.errorhandling.TechnicalException;

@Service
@ConditionalOnMissingBean(OzgCloudFileService.class)
public class DummyOzgCloudFileService implements OzgCloudFileService {

	private static final byte[] TEST_DATA = "Hello World!".getBytes();

	public static final OzgCloudFile DUMMY_FILE = OzgCloudFile.builder()
			.id(OzgCloudFileId.from("42"))
			.contentType("text/plain")
			.size(TEST_DATA.length)
			.name("helloWorld.txt")
			.build();

	@Override
	public OzgCloudFile getFile(OzgCloudFileId id) {
		return DUMMY_FILE;
	}

	@Override
	public void writeFileDataToStream(OzgCloudFileId id, OutputStream streamToWriteData) {
		try {
			streamToWriteData.write(TEST_DATA);
		} catch (IOException e) {
			throw new TechnicalException("Error writing dummy data.", e);
		}
	}

	@Override
	public OzgCloudFileId uploadFile(OzgCloudUploadFile file, InputStream dataStream) {
		IOUtils.closeQuietly(dataStream);
		return OzgCloudFileId.from("%s-%s".formatted(file.getFileName(), file.getVorgangId()));
	}

}
